@@ -2,6 +2,7 @@ package Text::PDF::Name;
 
 use strict;
 use vars qw(@ISA);
+no warnings qw(uninitialized);
 
 use Text::PDF::String;
 @ISA = qw(Text::PDF::String);
@@ -13,6 +14,24 @@ beginning with /)
 
 =head1 METHODS
 
+=head2 Text::PDF::Name->from_pdf($string)
+
+Creates a new string object (not a full object yet) from a given string.
+The string is parsed according to input criteria with escaping working, particular
+to Names.
+
+=cut
+
+
+sub from_pdf
+{
+    my ($class, $str) = @_;
+    my ($self) = $class->SUPER::from_pdf($str);
+    
+    $self->{'val'} =~ s/\#([0-9A-F][0-9A-F])/chr(hex($1))/ge;   # thanks to rlandrum@capitoladvantage.com
+    $self;
+}
+
 =head2 $n->convert
 
 Converts a name into a string by removing the / and converting any hex munging
